@@ -27,19 +27,24 @@ slConfig::slConfig( wxInputStream& in, const wxMBConv& conv )
 }
 #endif // wxUSE_STREAMS
 
+wxString slConfig::GlobalConfigPath() const
+{
+#ifdef __WXMSW__
+	wxString p (wxFileName::GetPathSeparator());
+		wxString global_config_path = wxFormat( _T("%s%s%s.global.conf") )
+													   % GetExecutableFolder()
+													   % p
+													   % ::GetAppName( true );
+#else
+	wxString global_config_path = IdentityString( _T("/etc/default/%s.conf"), true );
+#endif //__WXMSW__
+	return global_config_path;
+}
+
 void slConfig::SetupGlobalconfig()
 {
 	SetRecordDefaults( true );
-	#ifdef __WXMSW__
-		wxString p (wxFileName::GetPathSeparator());
-		wxString global_config_path = wxString::Format( _T("%s%s%s.global.conf"),
-													   GetExecutableFolder().c_str(),
-													   p.c_str(),
-													   ::GetAppName( true ).c_str()
-													   );
-	#else
-		wxString global_config_path = IdentityString( _T("/etc/default/%s.conf"), true );
-	#endif //__WXMSW__
+	const wxString global_config_path = GlobalConfigPath();
 
 	if (  wxFileName::FileExists( global_config_path ) )
 	{
