@@ -41,6 +41,7 @@ class Channel : public UserList, public SL::NonCopyable
     void Say( const wxString& message );
     void DoAction( const wxString& action );
     void Leave();
+	void Rejoin();
 
     void Said( User& who, const wxString& message );
 
@@ -89,13 +90,13 @@ class Channel : public UserList, public SL::NonCopyable
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
