@@ -252,7 +252,7 @@ find_tail_sequences(int fd, const char* bytes, size_t bytes_length, size_t count
 			if (  strncmp(source, "##", 2) != 0 ) {
 			    out.Insert(wxString(L'\0', 0), 0);
 			    wxLogMessage(_T("ChatLog::find_tail_sequences: fetching write buffer for %lu bytes"), sizeof(wxChar) * (line_length + 1));
-			    #if !defined(HAVE_WX28) || defined(SL_QT_MODE)
+                #if !defined(HAVE_WX28) || defined(SL_QT_MODE) || wxUSE_STL
 			    	wxStringBufferLength outzero_buf(out[0], sizeof(wxChar) * (line_length + 1));
 			    	wxConvUTF8.ToWChar(outzero_buf, line_length, source);
 			    	outzero_buf.SetLength(line_length);
