@@ -8,6 +8,7 @@
 #include "chatlog.h"
 #include "Helper/TextCompletionDatabase.hpp"
 #include "utils/mixins.hh"
+#include "utils/isink.h"
 
 class wxCommandEvent;
 class wxSizeEvent;
@@ -64,7 +65,7 @@ struct ChatLine
  * The nick list is optional and can be removed by setting show_nick_list in the
  * constructor to false.
  */
-class ChatPanel : public wxPanel, public SL::NonCopyable
+class ChatPanel : public wxPanel, public OnLoginSink<ChatPanel>, public SL::NonCopyable
 {
   public:
 
@@ -136,6 +137,8 @@ class ChatPanel : public wxPanel, public SL::NonCopyable
 
     void OnMenuItem( wxCommandEvent& event );
 
+	void OnLogin( OnLoginSink<ChatPanel>::EventDataType data );
+
   protected:
 
     void _SetChannel( Channel* channel );
@@ -218,13 +221,13 @@ enum
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
