@@ -41,9 +41,10 @@ class GlobalRecursiveError: public std::runtime_error
 class IGlobalObjectHolder
 {
 	public:
-			bool RegisterSelf();
-			virtual void Nullify() = 0;
-			virtual void Destroy() = 0;
+		virtual ~IGlobalObjectHolder(){}
+		bool RegisterSelf();
+		virtual void Nullify() = 0;
+		virtual void Destroy() = 0;
 };
 
 void DestroyGlobals();
@@ -114,13 +115,13 @@ int GlobalObjectHolder<T,I>::count = 0;
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
