@@ -21,4 +21,18 @@ private:
 	const wxSize m_default_size;
 };
 
+class WindowHintsPickle : public SL::NonCopyable
+{
+	public:
+		WindowHintsPickle ( const wxString& name, wxTopLevelWindow* window, const wxSize& default_size );
+		virtual ~WindowHintsPickle ();
+	protected:
+		void SaveAttributes();
+		void LoadAttributes();
+	private:
+		const wxString m_name;
+		wxTopLevelWindow* m_window;
+		const wxSize m_default_size;
+};
+
 #endif // WINDOWATTRIBUTESPICKLE_H
