@@ -8,7 +8,7 @@
 #include "ibattle.h"
 #include "utils/debug.h"
 #include "utils/conversion.h"
-#include "utils/math.h"
+#include <lslutils/misc.h>
 #include "uiutils.h"
 #include "settings.h"
 #include "ui.h" //only required for preset stuff
@@ -692,8 +692,8 @@ UserPosition IBattle::GetFreePosition()
     }
     if ( !taken )
     {
-      ret.x = clamp(map.info.positions[i].x, 0, map.info.width);
-      ret.y = clamp(map.info.positions[i].y, 0, map.info.height);
+      ret.x = LSL::Util::Clamp(map.info.positions[i].x, 0, map.info.width);
+      ret.y = LSL::Util::Clamp(map.info.positions[i].y, 0, map.info.height);
       return ret;
     }
   }
@@ -829,18 +829,16 @@ wxString IBattle::GetHostModHash() const
 bool IBattle::MapExists() const
 {
   return m_map_exists;
-  //return usync().MapExists( m_map_name, m_map.hash );
+//  return usync().MapExists( m_map.name, m_map.hash );
 }
 
 
 bool IBattle::ModExists() const
 {
   return m_mod_exists;
-  //return usync().ModExists( m_mod_name );
+//  return usync().ModExists( m_host_mod.name, m_host_mod.hash );
 }
 
-
-
 void IBattle::RestrictUnit( const wxString& unitname, int count )
 {
   m_restricted_units[ unitname ] = count;
@@ -925,7 +923,7 @@ bool IBattle::LoadOptionsPreset( const wxString& name )
     std::map<wxString,wxString> options = sett().GetHostingPreset( m_preset, i );
     if ( (OptionsWrapper::GameOption)i != OptionsWrapper::PrivateOptions )
     {
-	  for ( std::map<wxString,wxString>::const_iterator itor = options.begin(); itor != options.end(); itor++ )
+	  for ( std::map<wxString,wxString>::const_iterator itor = options.begin(); itor != options.end(); ++itor )
       {
             wxLogWarning( itor->first + _T(" ::: ") + itor->second );
             CustomBattleOptions().setSingleOption( itor->first, itor->second, (OptionsWrapper::GameOption)i );
@@ -1016,7 +1014,7 @@ void IBattle::SaveOptionsPreset( const wxString& name )
       opts[_T("numrects")] = TowxString( validrectcount );
 
       wxString restrictionsstring;
-	  for ( std::map<wxString, int>::const_iterator itor = m_restricted_units.begin(); itor != m_restricted_units.end(); itor++ )
+	  for ( std::map<wxString, int>::const_iterator itor = m_restricted_units.begin(); itor != m_restricted_units.end(); ++itor )
       {
         restrictionsstring << itor->first << _T('=') << TowxString(itor->second) << _T('\t');
       }
