@@ -5,7 +5,7 @@
 #include <wx/string.h>
 #include <wx/event.h>
 
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "user.h"
 #include "mmoptionswrapper.h"
 #include "userlist.h"
@@ -299,7 +299,7 @@ public:
 		virtual bool GetGUIListActiv() const { return m_opts.guilistactiv; }
 		virtual void SetGUIListActiv(bool Activ) { m_opts.guilistactiv = Activ; }
 
-		virtual void SetInGame( bool ingame ) { m_ingame = ingame; }
+		virtual void SetInGame( bool ingame );
 		virtual bool GetInGame() const { return m_ingame; }
 
 		virtual void SetBattleType( BattleType type ) { m_opts.battletype = type; }
@@ -392,6 +392,8 @@ public:
 
 		std::map<wxString, wxString> m_script_tags; // extra script tags to reload in the case of map/mod reload
 
+		virtual long GetBattleRunningTime() const; // returns 0 if not started
+
 protected:
 
 		void LoadScriptMMOpts( const wxString& sectionname, const SL::PDataList& node );
@@ -447,19 +449,21 @@ protected:
     UserVec m_internal_user_list; /// to store users from savegame/replay
 
     wxTimer* m_timer;
+
+    long m_start_time;
 };
 
 #endif // SPRINGLOBBY_HEADERGUARD_IBATTLE_H
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
