@@ -19,8 +19,17 @@ typedef int Sockerror;
 
 typedef int Protocolerror;
 
+#ifdef SL_QT_MODE
+#include <QObject>
+class IServerEvents : public QObject
+{
+	Q_OBJECT
+signals:
+	void saidBattle( int battleid, const QString& nick, const QString& msg );
+#else
 class IServerEvents
 {
+#endif
   public:
 	IServerEvents( ) {}
 	virtual ~IServerEvents() {}
@@ -127,6 +136,7 @@ class IServerEvents
 
 	virtual void OnFileDownload( bool autolaunch, bool autoclose, bool disconnectonrefuse, const wxString& FileName, const wxString& url, const wxString& description ) = 0;
 	virtual void OnSpringDownloadEvent( wxCommandEvent& event ) = 0;
+    virtual void OnForceJoinBattle( int battleid, const wxString& line ) = 0;
 
 };
 
