@@ -15,7 +15,7 @@
 #include "mainchattab.h"
 #include "utils/debug.h"
 #include "utils/conversion.h"
-#include "utils/math.h"
+#include <lslutils/misc.h>
 #include "utils/controls.h"
 #include "mainwindow.h"
 #include "channel/channel.h"
@@ -361,10 +361,10 @@ wxImage MainChatTab::ReplaceChannelStatusColour( wxBitmap img, const wxColour& c
 	wxImage::HSVValue origcolour = wxImage::RGBtoHSV( wxImage::RGBValue( colour.Red(), colour.Green(), colour.Blue() ) );
 
 	double bright = origcolour.value - 0.1 * origcolour.value;
-	bright = clamp( bright, 0.0, 1.0 );
+	bright = LSL::Util::Clamp( bright, 0.0, 1.0 );
 	wxImage::HSVValue hsvdarker1( origcolour.hue, origcolour.saturation, bright );
 	bright = origcolour.value - 0.5 * origcolour.value;
-	bright = clamp( bright, 0.0, 1.0 );
+	bright = LSL::Util::Clamp( bright, 0.0, 1.0 );
 	wxImage::HSVValue hsvdarker2( origcolour.hue, origcolour.saturation, bright );
 
 	wxImage::RGBValue rgbdarker1 = wxImage::HSVtoRGB( hsvdarker1 );
