@@ -41,12 +41,12 @@
 #include "server.h"
 #include "utils/debug.h"
 #include "utils/platform.h"
-#include "battlelisttab.h"
+#include "battlelist/battlelisttab.h"
 #include "mainchattab.h"
-#include "mainjoinbattletab.h"
-#include "battlelisttab.h"
-#include "mainsingleplayertab.h"
-#include "mainoptionstab.h"
+#include "hosting/mainjoinbattletab.h"
+#include "hosting/mainsingleplayertab.h"
+#include "battlelist/battlelisttab.h"
+#include "options/mainoptionstab.h"
 #include "springunitsync.h"
 #include "uiutils.h"
 #include "utils/misc.h"
@@ -54,10 +54,7 @@
 #include "playback/playbacktraits.h"
 #include "playback/playbacktab.h"
 #include "infodialog.h"
-#ifndef NO_TORRENT_SYSTEM
-	#include "maintorrenttab.h"
-	#include "torrentwrapper.h"
-#endif
+#include "maindownloadtab.h"
 #include "user.h"
 #include "mapselectdialog.h"
 
@@ -70,7 +67,7 @@
 #include "images/broom_tab_icon.png.h"
 #include "images/floppy_icon.png.h"
 
-#include "settings++/frame.h"
+#include "springsettings/frame.h"
 #include "utils/customdialogs.h"
 #include "utils/platform.h"
 
@@ -170,15 +167,11 @@ MainWindow::MainWindow( )
 	m_menuTools->Append(MENU_SCREENSHOTS, _("&View screenshots"));
 	m_menuTools->AppendSeparator();
 	m_menuTools->Append(MENU_USYNC, _("&Reload maps/games"));
+    m_menuTools->AppendSeparator();
 
-
-#ifndef NO_TORRENT_SYSTEM
-	m_menuTools->AppendSeparator();
-#endif
-	if (!sett().IsSelfUpdateDisabled() )
+    if (!sett().IsSelfUpdateDisabled() )
 		m_menuTools->Append(MENU_VERSION, _("Check for new Version"));
 
-
 	wxMenu *menuHelp = new wxMenu;
 	menuHelp->Append(MENU_GENERAL_HELP, _("&Help, tutorial and FAQ"));
 	menuHelp->Append(MENU_ABOUT, _("&About"));
@@ -211,9 +204,7 @@ MainWindow::MainWindow( )
 	m_sp_tab = new MainSinglePlayerTab( m_func_tabs );
 //	m_savegame_tab = new SavegameTab( m_func_tabs );
 	m_replay_tab = new ReplayTab ( m_func_tabs );
-#ifndef NO_TORRENT_SYSTEM
-	m_torrent_tab = new MainTorrentTab( m_func_tabs);
-#endif
+	m_torrent_tab = new MainDownloadTab( m_func_tabs);
 
     //use Insert so no Changepage events are triggered
     m_func_tabs->InsertPage( PAGE_CHAT,     m_chat_tab,     m_tab_names[PAGE_CHAT],     true  );
@@ -222,9 +213,7 @@ MainWindow::MainWindow( )
     m_func_tabs->InsertPage( PAGE_SINGLE,   m_sp_tab,       m_tab_names[PAGE_SINGLE],   false );
 //    m_func_tabs->InsertPage( PAGE_SAVEGAME, m_savegame_tab, m_tab_names[PAGE_SAVEGAME], false );
     m_func_tabs->InsertPage( PAGE_REPLAY,   m_replay_tab,   m_tab_names[PAGE_REPLAY],   false );
-#ifndef NO_TORRENT_SYSTEM
     m_func_tabs->InsertPage( PAGE_TORRENT,  m_torrent_tab,  m_tab_names[PAGE_TORRENT],  false );
-#endif
 
     LoadPerspectives();
 	SetTabIcons();
@@ -241,11 +230,12 @@ MainWindow::MainWindow( )
 	m_channel_chooser = new ChannelChooserDialog( this, -1, _("Choose channels to join") );
 
 	m_statusbar = new Statusbar( this );
-	SetStatusBar( m_statusbar );
+    SetStatusBar( m_statusbar );
     // re-enable eventhandling
     SetEvtHandlerEnabled( true );
 
 	UpdateMainAppHasFocus(m_has_focus);
+    Connect( MainwindowMessageEvent, wxCommandEventHandler( MainWindow::OnMessage ), NULL, this );
 }
 
 wxBitmap MainWindow::GetTabIcon( const unsigned char* data, size_t size ) const
@@ -258,17 +248,15 @@ wxBitmap MainWindow::GetTabIcon( const unsigned char* data, size_t size ) const
 
 void MainWindow::SetTabIcons()
 {
-		unsigned int count = 0;
+    unsigned int count = 0;
     m_func_tabs->SetPageBitmap( count++, GetTabIcon( chat_icon_png, sizeof(chat_icon_png)  ) );
     m_func_tabs->SetPageBitmap( count++, GetTabIcon( join_icon_png, sizeof(join_icon_png)  ) );
     m_func_tabs->SetPageBitmap( count++, GetTabIcon( broom_tab_icon_png, sizeof(broom_tab_icon_png) ) );
     m_func_tabs->SetPageBitmap( count++, GetTabIcon( single_player_icon_png , sizeof (single_player_icon_png) ) );
     m_func_tabs->SetPageBitmap( count++, GetTabIcon( floppy_icon_png , sizeof (floppy_icon_png) ) );
     m_func_tabs->SetPageBitmap( count++, GetTabIcon( replay_icon_png , sizeof (replay_icon_png) ) );
-#ifndef NO_TORRENT_SYSTEM
     m_func_tabs->SetPageBitmap( count++, GetTabIcon(  downloads_icon_png , sizeof (downloads_icon_png) ) );
-#endif
-		m_func_tabs->SetPageBitmap( count++, GetTabIcon( options_icon_png , sizeof (options_icon_png) ) );
+    m_func_tabs->SetPageBitmap( count++, GetTabIcon( options_icon_png , sizeof (options_icon_png) ) );
     Refresh();
 }
 
@@ -348,7 +336,19 @@ void MainWindow::OnSetFocus(wxFocusEvent&)
 void MainWindow::OnKillFocus(wxFocusEvent&)
 {
 	m_has_focus = false;
-	UpdateMainAppHasFocus(m_has_focus);
+    UpdateMainAppHasFocus(m_has_focus);
+}
+
+void MainWindow::OnMessage(wxCommandEvent &event)
+{
+    customMessageBoxNoModal(SL_MAIN_ICON, event.GetString());
+}
+
+void MainWindow::AddMessageEvent(const wxString& message)
+{
+    wxCommandEvent evt(MainwindowMessageEvent, wxNewId());
+    evt.SetString(message);
+    AddPendingEvent(evt);
 }
 
 bool MainWindow::HasFocus() const
@@ -421,13 +421,12 @@ MainWindow::ReplayTab& MainWindow::GetReplayTab()
 //    return *m_savegame_tab;
 //}
 
-#ifndef NO_TORRENT_SYSTEM
-MainTorrentTab& MainWindow::GetTorrentTab()
+MainDownloadTab& MainWindow::GetDownloadTab()
 {
   ASSERT_EXCEPTION( m_torrent_tab  != 0, _T("m_torrent_tab = 0") );
   return *m_torrent_tab ;
 }
-#endif
+
 ChatPanel* MainWindow::GetActiveChatPanel()
 {
   unsigned int index = m_func_tabs->GetSelection();
@@ -437,7 +436,6 @@ ChatPanel* MainWindow::GetActiveChatPanel()
   return 0;
 }
 
-
 ChatPanel* MainWindow::GetChannelChatPanel( const wxString& channel )
 {
   return m_chat_tab->GetChannelChatPanel( channel );
@@ -722,7 +720,7 @@ const MainWindow::TabNames& MainWindow::GetTabNames()
 }
 
 #ifdef __WXMSW__
-	#include "battleroomtab.h"
+	#include <hosting/battleroomtab.h>
 #endif
 
 void MainWindow::LoadPerspectives( const wxString& pers_name )
