@@ -14,9 +14,7 @@ class MainChatTab;
 class BattleListTab;
 class MainJoinBattleTab;
 class MainSinglePlayerTab;
-#ifndef NO_TORRENT_SYSTEM
-class MainTorrentTab;
-#endif
+class MainDownloadTab;
 class wxBoxSizer;
 class SLNotebook;
 class wxListbook;
@@ -38,13 +36,12 @@ class wxCloseEvent;
 class Statusbar;
 class OptionsDialog;
 class ReplayTraits;
-template < class Traits >
-class PlaybackTab;
 class wxFocusEvent;
 
-//class SavegameTraits;
-//template < class Traits >
-//class SavegameTab;
+template < class Traits >
+class PlaybackTab;
+
+const wxEventType MainwindowMessageEvent = wxNewEventType();
 
 //! @brief wxFrame that contains the main window of the client.
 class MainWindow : public wxFrame, public WindowAttributesPickle
@@ -101,6 +98,8 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
     void OnClose( wxCloseEvent& );
 	void OnSetFocus(wxFocusEvent&);
 	void OnKillFocus(wxFocusEvent&);
+    void OnMessage( wxCommandEvent& event );
+    void AddMessageEvent( const wxString& message );
 
     void OnTabsChanged( wxAuiNotebookEvent& event );
     MainChatTab& GetChatTab();
@@ -109,9 +108,8 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
     MainSinglePlayerTab& GetSPTab();
     ReplayTab& GetReplayTab();
 //    SavegameTab& GetSavegameTab();
-    #ifndef NO_TORRENT_SYSTEM
-    MainTorrentTab& GetTorrentTab();
-    #endif
+	MainDownloadTab& GetDownloadTab();
+
     ChatPanel* GetActiveChatPanel();
     ChatPanel* GetChannelChatPanel( const wxString& channel );
 
@@ -126,8 +124,6 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
 
 	bool HasFocus() const;
 
-
-
   protected:
 
     wxMenuItem* m_settings_menu;
@@ -143,19 +139,16 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
     BattleListTab* m_list_tab;
     MainJoinBattleTab* m_join_tab;
     MainSinglePlayerTab* m_sp_tab;
-    #ifndef NO_TORRENT_SYSTEM
-    MainTorrentTab* m_torrent_tab;
-    #endif
+	MainDownloadTab* m_torrent_tab;
 	OptionsDialog* m_opts_dialog;
 
     AutojoinChannelDialog* m_autojoin_dialog;
-    settings_frame* se_frame;
     friend class settings_frame;
+    settings_frame* se_frame;
     bool se_frame_active;
     ChannelChooserDialog* m_channel_chooser;
 
     ReplayTab* m_replay_tab;
-//    SavegameTab* m_savegame_tab;
 
 	wxBitmap GetTabIcon( const unsigned char* data, size_t size  ) const;
 	wxString AddPerspectivePostfix( const wxString& pers_name ) const;
@@ -208,10 +201,8 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
                     Add( _("Singleplayer") );
 //                    Add( _("Savegames") );
                     Add( _("Replays") );
-                #ifndef NO_TORRENT_SYSTEM
-                    Add( _("Downloads") );
-                #endif
-                }
+					Add( _("Downloads") );
+				}
         };
         static TabNames m_tab_names;
 
@@ -223,21 +214,13 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
         static const unsigned int PAGE_SINGLE  = 3;
         static const unsigned int PAGE_REPLAY  = 4;
 //        static const unsigned int PAGE_SAVEGAME = 4;
-
-        #ifndef NO_TORRENT_SYSTEM
         static const unsigned int PAGE_TORRENT = 5;
-        #endif
 
         static const unsigned int OPT_PAGE_SPRING   = 0;
         static const unsigned int OPT_PAGE_CHAT     = 1;
-        #ifndef NO_TORRENT_SYSTEN
         static const unsigned int OPT_PAGE_TORRENT  = 2;
         static const unsigned int OPT_PAGE_GENERAL  = 3;
         static const unsigned int OPT_PAGE_GROUPS   = 4;
-        #else
-        static const unsigned int OPT_PAGE_GENERAL  = 2;
-        static const unsigned int OPT_PAGE_GROUPS   = 3;
-        #endif
 
         static const TabNames& GetTabNames();
 
