@@ -3,6 +3,7 @@
 
 #include <wx/image.h>
 #include <wx/string.h>
+#include <wx/panel.h>
 
 #include "ibattle.h"
 #include "springunitsync.h"
@@ -211,9 +212,7 @@ class MapCtrl : public wxPanel
       IM_Metalmap, // entries must be consecutively numbered (without gaps)
       IM_Heightmap,
 	  IM_Count     // must be last one
-    };
-
-    InfoMap m_current_infomap;
+    } m_current_infomap;
 
   DECLARE_EVENT_TABLE()
 };
