@@ -3,7 +3,7 @@
 #ifndef SPRINGLOBBY_HEADERGUARD_MAPGRIDCTRL_H
 #define SPRINGLOBBY_HEADERGUARD_MAPGRIDCTRL_H
 
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include <wx/bitmap.h>
 #include <wx/image.h>
 #include <wx/panel.h>
@@ -195,13 +195,13 @@ class MapGridCtrl : public wxPanel
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
