@@ -588,7 +588,7 @@ void OptionsWrapper::ParseSectionMap( mmSectionTree& section_tree, const SpringU
 
     RelationMapIter rit = relation_map.begin();
     // no more items in the map means we've added them all
-    while ( relation_map.size() > 0 )
+    while ( !relation_map.empty())
     {
         RelationMapIter rit_next = rit; // in case we need to delete
         ++rit_next;
@@ -620,11 +620,13 @@ mmSectionTree::mmSectionTree()
 
 mmSectionTree::~mmSectionTree()
 {
-    #ifndef NDEBUG
-        m_tree->Flush();
-    #else //no need to clutter tempfile directory if we're not debugging
-        m_tree->DeleteAll();
-    #endif
+	if (m_tree!=NULL) {
+		#ifndef NDEBUG
+		m_tree->Flush();
+		#else //no need to clutter tempfile directory if we're not debugging
+		m_tree->DeleteAll();
+		#endif
+	}
 }
 
 void mmSectionTree::AddSection ( const wxString& parentpath, const mmOptionSection& section )
