@@ -13,7 +13,7 @@
 #include <algorithm>
 
 #include "nicklistctrl.h"
-#include "utils/math.h"
+#include <lslutils/misc.h>
 #include "utils/debug.h"
 #include "utils/conversion.h"
 #include "iconimagelist.h"
@@ -197,7 +197,7 @@ void NickListCtrl::SetTipWindowText( const long item_hit, const wxPoint& positio
 
 wxListItemAttr* NickListCtrl::GetItemAttr( long item ) const
 {
-	if ( m_data[item] && item < ( long ) m_data.size() && item > -1 ) {
+	if ( item > -1 && item < ( long ) m_data.size() && m_data[item] ) {
 		const User& u = *m_data[item];
 		wxString name = u.GetNick();
 		return HighlightItemUser( name );
@@ -214,7 +214,7 @@ int NickListCtrl::GetIndexFromData( const DataType& data ) const
 {
 	const User* user = data;
 	static long seekpos;
-	seekpos = clamp( seekpos, 0l , ( long )m_data.size() );
+	seekpos = LSL::Util::Clamp( seekpos, 0l , ( long )m_data.size() );
 	int index = seekpos;
 
 	for ( DataCIter f_idx = m_data.begin() + seekpos; f_idx != m_data.end() ; ++f_idx )
