@@ -22,7 +22,7 @@
 #include "../settings.h"
 #include "../springunitsync.h"
 #include "../mapctrl.h"
-#include "../battleroomlistctrl.h"
+#include <hosting/battleroomlistctrl.h>
 
 #include "playbackfilter.h"
 #include "../iconimagelist.h"
@@ -283,14 +283,14 @@ void PlaybackTab<PlaybackTraits>::OnWatch( wxCommandEvent& /*unused*/ )
 			PlaybackType& rep = playbacklist<ListType>().GetPlaybackById( m_sel_replay_id );
 
 			std::map<wxString, wxString> versionlist = sett().GetSpringVersionList();
-			if ( versionlist.size() == 0 ) {
+			if ( versionlist.empty()) {
 				wxLogWarning( _T( "can't get spring version from any unitsync" ) );
 				customMessageBox( SL_MAIN_ICON,  _( "Couldn't get your spring versions from any unitsync library." ), _( "Spring error" ), wxICON_EXCLAMATION | wxOK );
 				AskForceWatch( rep );
 				return;
 			}
 			bool versionfound = false;
-			for ( std::map<wxString, wxString>::const_iterator itor = versionlist.begin(); itor != versionlist.end(); itor++ ) {
+			for ( std::map<wxString, wxString>::const_iterator itor = versionlist.begin(); itor != versionlist.end(); ++itor ) {
 				if ( itor->second == rep.SpringVersion ) {
 					if ( sett().GetCurrentUsedSpringIndex() != itor->first ) {
 						wxLogMessage( _T( "%s requires version: %s, switching to profile: %s" ), type.c_str(), rep.SpringVersion.c_str(), itor->first.c_str() );
@@ -305,7 +305,7 @@ void PlaybackTab<PlaybackTraits>::OnWatch( wxCommandEvent& /*unused*/ )
 			if ( !versionfound ) {
 				wxString message = wxFormat( _( "No compatible installed spring version has been found, this %s requires version: %s\n" ) ) % type% rep.SpringVersion;
 				message << _( "Your current installed versions are:" );
-				for ( std::map<wxString, wxString>::const_iterator itor = versionlist.begin(); itor != versionlist.end(); itor++ ) message << _T( " " ) << itor->second;
+				for ( std::map<wxString, wxString>::const_iterator itor = versionlist.begin(); itor != versionlist.end(); ++itor ) message << _T( " " ) << itor->second;
 				customMessageBox( SL_MAIN_ICON, message, _( "Spring error" ), wxICON_EXCLAMATION | wxOK );
 				wxLogWarning ( _T( "no spring version supported by this replay found" ) );
 				AskForceWatch( rep );
@@ -316,12 +316,7 @@ void PlaybackTab<PlaybackTraits>::OnWatch( wxCommandEvent& /*unused*/ )
 			if ( watchable )
 				rep.battle.StartSpring();
 			else {
-#ifdef NO_TORRENT_SYSTEM
-				wxString downloadProc = _( "Do you want me to take you to the download page?" );
-#else
 				wxString downloadProc = _( "Should i try to download it for you?\nYou can see the progress in the \"Download Manager\" tab." );
-#endif
-
 				OfflineBattle& battle = rep.battle;
 
 				if ( !battle.ModExists() ) {
