@@ -22,15 +22,12 @@
 #include "uiutils.h"
 #include "server.h"
 #include "battle.h"
-#include "httpdownloader.h"
+#include <downloader/httpdownloader.h>
 #include "settings.h"
 #include "utils/customdialogs.h"
 #include "utils/tasutil.h"
 #include "utils/uievents.h"
 
-#ifndef NO_TORRENT_SYSTEM
-#include "torrentwrapper.h"
-#endif
 #include "globalsmanager.h"
 
 BEGIN_EVENT_TABLE(ServerEvents, wxEvtHandler)
@@ -282,7 +279,6 @@ void ServerEvents::OnJoinedBattle( int battleid, const wxString& hash )
         Battle& battle = m_serv.GetBattle( battleid );
 
         battle.SetHostMod( battle.GetHostModName(), hash );
-
         UserBattleStatus& bs = m_serv.GetMe().BattleStatus();
         bs.spectator = false;
 
