@@ -31,15 +31,15 @@
 #include "nonportable.h"
 #include "utils/conversion.h"
 #include "utils/debug.h"
-#include "utils/math.h"
+#include <lslutils/misc.h>
 #include "utils/platform.h"
 #include "uiutils.h"
-#include "battlelistfiltervalues.h"
+#include "battlelist/battlelistfiltervalues.h"
 #include "playback/playbackfiltervalues.h"
 #include "globalsmanager.h"
 #include "springunitsynclib.h"
 #include "customlistctrl.h"
-#include "settings++/presets.h"
+#include "springsettings/presets.h"
 #include "Helper/sortutil.h"
 #include "mainwindow.h"
 #ifdef SL_DUMMY_COL
@@ -356,9 +356,9 @@ bool Settings::ShouldAddDefaultServerSettings()
 void Settings::SetDefaultServerSettings()
 {
 	SetServer(  DEFSETT_DEFAULT_SERVER_NAME,  DEFSETT_DEFAULT_SERVER_HOST, DEFSETT_DEFAULT_SERVER_PORT );
-	SetServer( _T( "Backup server 1" ), _T( "springbackup1.servegame.com" ), 8200 );
-	SetServer( _T( "Backup server 2" ), _T( "springbackup2.servegame.org" ), 8200 );
-	SetServer( _T( "Test server" ), _T( "taspringmaster.servegame.com" ), 8300 );
+	SetServer( _T( "Backup server 1" ), _T( "lobby1.springlobby.info" ), 8200 );
+	SetServer( _T( "Backup server 2" ), _T( "lobby2.springlobby.info" ), 8200 );
+//	SetServer( _T( "Test server" ), _T( "taspringmaster.servegame.com" ), 8300 );
 	SetDefaultServer( DEFSETT_DEFAULT_SERVER_NAME );
 }
 
@@ -631,7 +631,7 @@ void Settings::SetWindowWidth( const wxString& window, const int value )
 {
 	m_config->Write(
 	    _T( "/GUI/" ) + window + _T( "/width" ),
-	    clamp(  value,
+	    LSL::Util::Clamp(  value,
 	            wxSystemSettings::GetMetric( wxSYS_WINDOWMIN_X ),
 	            wxSystemSettings::GetMetric( wxSYS_SCREEN_X )
 	         )
@@ -651,7 +651,7 @@ void Settings::SetWindowHeight( const wxString& window, const int value )
 {
 	m_config->Write(
 	    _T( "/GUI/" ) + window + _T( "/height" ),
-	    clamp(  value,
+	    LSL::Util::Clamp(  value,
 	            wxSystemSettings::GetMetric( wxSYS_WINDOWMIN_Y ),
 	            wxSystemSettings::GetMetric( wxSYS_SCREEN_Y )
 	         )
@@ -671,7 +671,7 @@ void Settings::SetWindowTop( const wxString& window, const int value )
 {
 	m_config->Write(
 	    _T( "/GUI/" ) + window + _T( "/top" ),
-	    clamp( value,
+	    LSL::Util::Clamp( value,
 	           0,
 	           wxSystemSettings::GetMetric( wxSYS_SCREEN_Y ) - 20
 	         )
@@ -690,7 +690,7 @@ void Settings::SetWindowLeft( const wxString& window, const int value )
 {
 	m_config->Write(
 	    _T( "/GUI/" ) + window + _T( "/left" ),
-	    clamp( value,
+	    LSL::Util::Clamp( value,
 	           0,
 	           wxSystemSettings::GetMetric( wxSYS_SCREEN_X ) - 20
 	         )
@@ -1850,14 +1850,15 @@ void Settings::ClearTorrentListToResume()
 
 wxFileName Settings::GetTorrentDir()
 {
+
 	wxFileName torrentDir( GetLobbyWriteDir() );
 	torrentDir.AppendDir( _T( "torrents" ) );
-
+/*
 	if ( !torrentDir.DirExists() )
 	{
 		if ( !torrentDir.Mkdir( 0755 ) ) torrentDir.Clear();
 	}
-
+*/
 	return torrentDir;
 }
 
@@ -1865,12 +1866,12 @@ wxFileName Settings::GetTorrentDataDir()
 {
 	wxFileName torrentDir( GetLobbyWriteDir() );
 	torrentDir.AppendDir( _T( "downloads" ) );
-
+/*
 	if ( !torrentDir.DirExists() )
 	{
 		if ( !torrentDir.Mkdir( 0755 ) ) torrentDir.Clear();
 	}
-
+*/
 	return torrentDir;
 }
 
