@@ -38,9 +38,6 @@
 #include "springunitsync.h"
 #include "nonportable.h"
 #include "tdfcontainer.h"
-#ifndef NO_TORRENT_SYSTEM
-#include "torrentwrapper.h"
-#endif
 #include "globalsmanager.h"
 
 #ifdef SL_QT_MODE
@@ -123,7 +120,7 @@ bool Spring::Run( Battle& battle )
     return false;
   }
 
-  #ifndef NO_TORRENT_SYSTEM
+  #if 0 //TODO: BD, isn't this SUPER obsolete
   wxString CommandForAutomaticTeamSpeak = _T("SCRIPT|") + battle.GetFounder().GetNick() + _T("|");
   for ( UserList::user_map_t::size_type i = 0; i < battle.GetNumUsers(); i++ )
   {
@@ -442,7 +439,7 @@ wxString Spring::WriteScriptTxt( IBattle& battle ) const
 			tdf.Append( _T("NumRestrictions"), units.size());
 			tdf.EnterSection( _T("RESTRICT") );
 				int restrictcount = 0;
-				for ( std::map<wxString, int>::const_iterator itor = units.begin(); itor != units.end(); itor++ )
+				for ( std::map<wxString, int>::const_iterator itor = units.begin(); itor != units.end(); ++itor )
 				{
 						tdf.Append(_T("Unit") + TowxString( restrictcount ), itor->first );
 						tdf.Append(_T("Limit") + TowxString( restrictcount ), itor->second );
