@@ -42,11 +42,8 @@
 #include "springunitsync.h"
 #include "channel/channel.h"
 #include "utils/customdialogs.h"
-#include "utils/downloader.h"
-#include "settings++/se_utils.h"
-#ifndef NO_TORRENT_SYSTEM
-#include "torrentwrapper.h"
-#endif
+#include "springsettings/se_utils.h"
+#include "downloader/prdownloader.h"
 #include "updater/updater.h"
 #include "globalsmanager.h"
 #include "gui/notificationmanager.h"
@@ -55,12 +52,20 @@
 #include "playback/playbacktab.h"
 #include "defines.h"
 #include "customizations.h"
-#include "alsound.h"
+#include "sound/alsound.h"
 #include "mapselectdialog.h"
+#ifdef HAVE_CONFIG_H
+#include "springlobby_config.h"
+#else
+	#define VERSION "unknown"
+#endif
 
 #include <wx/debugrpt.h>
 #include "utils/misc.h"
 
+#if wxUSE_UNIX
+	#include <X11/Xlib.h> 
+#endif
 const unsigned int TIMER_ID         = 101;
 const unsigned int TIMER_INTERVAL   = 100;
 
@@ -81,6 +86,9 @@ SpringLobbyApp::SpringLobbyApp()
     m_crash_handle_disable( false ),
 	m_appname( _T("SpringLobby") )
 {
+#if wxUSE_UNIX
+XInitThreads();
+#endif
 }
 
 SpringLobbyApp::~SpringLobbyApp()
@@ -125,6 +133,8 @@ bool SpringLobbyApp::OnInit()
     wxLogChain* logchain = 0;
 	wxLogWindow *loggerwin = InitializeLoggingTargets( 0, m_log_console, m_log_file_path, m_log_window_show, !m_crash_handle_disable, m_log_verbosity, logchain );
 
+	wxLogMessage( _T("SpringLobby %s started"), _T(VERSION));
+
     //this needs to called _before_ mainwindow instance is created
     wxInitAllImageHandlers();
     wxFileSystem::AddHandler(new wxZipFSHandler);
@@ -217,13 +227,6 @@ bool SpringLobbyApp::OnInit()
 
     ui().mw().SetLogWin( loggerwin, logchain );
 
-#ifndef NO_TORRENT_SYSTEM
-    plasmaInterface();
-//    plasmaInterface().InitResourceList();
-//	plasmaInterface().FetchResourceList();
-#endif
-
-
     return true;
 }
 
