@@ -31,6 +31,7 @@
 #include "utils/debug.h"
 #include "utils/conversion.h"
 #include "utils/misc.h"
+#include <lslutils/misc.h>
 #include "utils/globalevents.h"
 #include "utils/uievents.h"
 
@@ -69,7 +70,7 @@ SpringUnitSync::~SpringUnitSync()
 
 static int CompareStringNoCase(const wxString& first, const wxString& second)
 {
-	return first.CmpNoCase(second);
+    return first.CmpNoCase(second);
 }
 
 bool SpringUnitSync::FastLoadUnitSyncLib( const wxString& unitsyncloc )
@@ -151,6 +152,10 @@ void SpringUnitSync::PopulateArchiveList()
   m_maps_unchained_hash.clear();
   m_mods_unchained_hash.clear();
   m_shortname_to_name_map.clear();
+  m_mapinfo_cache.Clear();
+  m_sides_cache.Clear();
+  m_maps_archive_name.clear();
+  m_mods_archive_name.clear();
 
   int numMaps = susynclib().GetMapCount();
   for ( int i = 0; i < numMaps; i++ )
@@ -289,7 +294,7 @@ bool SpringUnitSync::ModExists( const wxString& modname ) const
 
 bool SpringUnitSync::ModExists( const wxString& modname, const wxString& hash ) const
 {
-  LocalArchivesVector::const_iterator itor = m_mods_list.find(modname);
+  const LocalArchivesVector::const_iterator itor = m_mods_list.find(modname);
   if ( itor == m_mods_list.end() ) return false;
   return itor->second == hash;
 }
@@ -359,7 +364,7 @@ bool SpringUnitSync::MapExists( const wxString& mapname ) const
 
 bool SpringUnitSync::MapExists( const wxString& mapname, const wxString& hash ) const
 {
-  LocalArchivesVector::const_iterator itor = m_maps_list.find(mapname);
+  const LocalArchivesVector::const_iterator itor = m_maps_list.find(mapname);
   if ( itor == m_maps_list.end() ) return false;
   return itor->second == hash;
 }
@@ -596,7 +601,7 @@ wxImage SpringUnitSync::GetImage( const wxString& modname, const wxString& image
 		ASSERT_EXCEPTION( FileSize, _T("image has size 0") );
 	}
 
-	uninitialized_array<char> FileContent(FileSize);
+    LSL::Util::uninitialized_array<char> FileContent(FileSize);
 	susynclib().ReadFileVFS(ini, FileContent, FileSize);
 	wxMemoryInputStream FileContentStream( FileContent, FileSize );
 
@@ -672,15 +677,6 @@ wxArrayString SpringUnitSync::GetAIList( const wxString& modname ) const
 			if ( ret.Index( jarlist[i].BeforeLast( '/') ) == wxNOT_FOUND ) ret.Add ( jarlist[i] ); // don't add duplicates
 		}
 
-		// luaai
-		try
-		{
-			const int LuaAICount = susynclib().GetLuaAICount( modname );
-			for ( int i = 0; i < LuaAICount; i++ )
-			{
-				 ret.Add( _T( "LuaAI:" ) +  susynclib().GetLuaAIName( i ) );
-			}
-		} CATCH_ANY
 	}
 
   return ret;
@@ -739,7 +735,7 @@ wxArrayString SpringUnitSync::GetUnitsList( const wxString& modname )
   } catch(...)
   {
     susynclib().SetCurrentMod( modname );
-    while ( susynclib().ProcessUnitsNoChecksum() ) {}
+    while ( susynclib().ProcessUnitsNoChecksum() > 0 ) {}
     unsigned int unitcount = susynclib().GetUnitCount();
     for ( unsigned int i = 0; i < unitcount; i++ )
     {
@@ -978,6 +974,13 @@ void SpringUnitSync::SetSpringDataPath( const wxString& path )
   susynclib().SetSpringConfigString( _T("SpringData"), path );
 }
 
+bool SpringUnitSync::GetSpringDataPath(wxString& path)
+{
+	path = susynclib().GetSpringDataDir();
+	return true;
+}
+
+
 
 wxString SpringUnitSync::GetFileCachePath( const wxString& name, const wxString& hash, bool IsMod )
 {
@@ -1351,7 +1354,7 @@ wxString SpringUnitSync::GetTextfileAsString( const wxString& modname, const wxS
 		return wxEmptyString;
 	}
 
-	uninitialized_array<char> FileContent(FileSize);
+    LSL::Util::uninitialized_array<char> FileContent(FileSize);
 	susynclib().ReadFileVFS(ini, FileContent, FileSize);
 	return wxString( FileContent, wxConvAuto(), size_t( FileSize ) );
 }
