@@ -12,6 +12,7 @@
 #include "utils/debug.h"
 #include "utils/conversion.h"
 #include "utils/misc.h"
+#include <lslutils/misc.h>
 #include "globalsmanager.h"
 
 #define LOCK_UNITSYNC wxCriticalSectionLocker lock_criticalsection(m_lock)
@@ -24,11 +25,161 @@
 
 
 SpringUnitSyncLib::SpringUnitSyncLib():
-  m_loaded(false),
-  m_libhandle(NULL),
-  m_path(wxEmptyString),
-  m_init(NULL),
-  m_uninit(NULL)
+	m_loaded(false),
+	m_libhandle(NULL),
+	m_path(wxEmptyString),
+	m_init(NULL),
+	m_uninit(NULL),
+	m_get_next_error(NULL),
+	m_get_writeable_data_dir(NULL),
+	m_get_data_dir_by_index(NULL),
+	m_get_data_dir_count(NULL),
+	m_get_map_count(NULL),
+	m_get_map_checksum(NULL),
+	m_get_map_name(NULL),
+	m_get_map_description(NULL),
+	m_get_map_author(NULL),
+	m_get_map_width(NULL),
+	m_get_map_height(NULL),
+	m_get_map_tidalStrength(NULL),
+	m_get_map_windMin(NULL),
+	m_get_map_windMax(NULL),
+	m_get_map_gravity(NULL),
+	m_get_map_resource_count(NULL),
+	m_get_map_resource_name(NULL),
+	m_get_map_resource_max(NULL),
+	m_get_map_resource_extractorRadius(NULL),
+	m_get_map_pos_count(NULL),
+	m_get_map_pos_x(NULL),
+	m_get_map_pos_z(NULL),
+	m_get_map_info_ex(NULL),
+	m_get_minimap(NULL),
+	m_get_infomap_size(NULL),
+	m_get_infomap(NULL),
+	m_get_mod_checksum(NULL),
+	m_get_mod_index(NULL),
+	m_get_mod_name(NULL),
+	m_get_mod_count(NULL),
+	m_get_mod_archive(NULL),
+	m_get_side_count(NULL),
+	m_get_side_name(NULL),
+	m_add_all_archives(NULL),
+	m_remove_all_archives(NULL),
+	m_get_unit_count(NULL),
+	m_get_unit_name(NULL),
+	m_get_unit_full_name(NULL),
+	m_proc_units_nocheck(NULL),
+	m_init_find_vfs(NULL),
+	m_find_files_vfs(NULL),
+	m_open_file_vfs(NULL),
+	m_file_size_vfs(NULL),
+	m_read_file_vfs(NULL),
+	m_close_file_vfs(NULL),
+	m_init_dirlist_vfs(NULL),
+	m_init_subdirs_vfs(NULL),
+	m_get_spring_version(NULL),
+	m_process_units(NULL),
+	m_add_archive(NULL),
+	m_get_archive_checksum(NULL),
+	m_get_archive_path(NULL),
+	m_get_map_archive_count(NULL),
+	m_get_map_archive_name(NULL),
+	m_get_map_checksum_from_name(NULL),
+	m_get_primary_mod_short_name(NULL),
+	m_get_primary_mod_version(NULL),
+	m_get_primary_mod_mutator(NULL),
+	m_get_primary_mod_game(NULL),
+	m_get_primary_mod_short_game(NULL),
+	m_get_primary_mod_description(NULL),
+	m_get_primary_mod_archive(NULL),
+	m_get_primary_mod_archive_count(NULL),
+	m_get_primary_mod_archive_list(NULL),
+	m_get_primary_mod_checksum_from_name(NULL),
+	m_get_mod_valid_map_count(NULL),
+	m_get_valid_map(NULL),
+	m_get_luaai_count(NULL),
+	m_get_luaai_name(NULL),
+	m_get_luaai_desc(NULL),
+	m_get_map_option_count(NULL),
+	m_get_custom_option_count(NULL),
+	m_get_mod_option_count(NULL),
+	m_get_skirmish_ai_option_count(NULL),
+	m_get_option_key(NULL),
+	m_get_option_name(NULL),
+	m_get_option_desc(NULL),
+	m_get_option_type(NULL),
+	m_get_option_section(NULL),
+	m_get_option_style(NULL),
+	m_get_option_bool_def(NULL),
+	m_get_option_number_def(NULL),
+	m_get_option_number_min(NULL),
+	m_get_option_number_max(NULL),
+	m_get_option_number_step(NULL),
+	m_get_option_string_def(NULL),
+	m_get_option_string_max_len(NULL),
+	m_get_option_list_count(NULL),
+	m_get_option_list_def(NULL),
+	m_get_option_list_item_key(NULL),
+	m_get_option_list_item_name(NULL),
+	m_get_option_list_item_desc(NULL),
+	m_open_archive(NULL),
+	m_close_archive(NULL),
+	m_find_Files_archive(NULL),
+	m_open_archive_file(NULL),
+	m_read_archive_file(NULL),
+	m_close_archive_file(NULL),
+	m_size_archive_file(NULL),
+	m_set_spring_config_file_path(NULL),
+	m_get_spring_config_file_path(NULL),
+	m_set_spring_config_float(NULL),
+	m_get_spring_config_float(NULL),
+	m_get_spring_config_int(NULL),
+	m_get_spring_config_string(NULL),
+	m_set_spring_config_string(NULL),
+	m_set_spring_config_int(NULL),
+	m_get_skirmish_ai_count(NULL),
+	m_get_skirmish_ai_info_count(NULL),
+	m_get_skirmish_ai_info_key(NULL),
+	m_get_skirmish_ai_info_value(NULL),
+	m_get_skirmish_ai_info_description(NULL),
+	m_parser_close(NULL),
+	m_parser_open_file(NULL),
+	m_parser_open_source(NULL),
+	m_parser_execute(NULL),
+	m_parser_error_log(NULL),
+	m_parser_add_table_int(NULL),
+	m_parser_add_table_string(NULL),
+	m_parser_end_table(NULL),
+	m_parser_add_int_key_int_value(NULL),
+	m_parser_add_string_key_int_value(NULL),
+	m_parser_add_int_key_bool_value(NULL),
+	m_parser_add_string_key_bool_value(NULL),
+	m_parser_add_int_key_float_value(NULL),
+	m_parser_add_string_key_float_value(NULL),
+	m_parser_add_int_key_string_value(NULL),
+	m_parser_add_string_key_string_value(NULL),
+	m_parser_root_table(NULL),
+	m_parser_root_table_expression(NULL),
+	m_parser_sub_table_int(NULL),
+	m_parser_sub_table_string(NULL),
+	m_parser_sub_table_expression(NULL),
+	m_parser_pop_table(NULL),
+	m_parser_key_int_exists(NULL),
+	m_parser_key_string_exists(NULL),
+	m_parser_int_key_get_type(NULL),
+	m_parser_string_key_get_type(NULL),
+	m_parser_int_key_get_list_count(NULL),
+	m_parser_int_key_get_list_entry(NULL),
+	m_parser_string_key_get_list_count(NULL),
+	m_parser_string_key_get_list_entry(NULL),
+	m_parser_int_key_get_int_value(NULL),
+	m_parser_string_key_get_int_value(NULL),
+	m_parser_int_key_get_bool_value(NULL),
+	m_parser_string_key_get_bool_value(NULL),
+	m_parser_int_key_get_float_value(NULL),
+	m_parser_string_key_get_float_value(NULL),
+	m_parser_int_key_get_string_value(NULL),
+	m_parser_string_key_get_string_value(NULL)
 {
 }
 
@@ -239,10 +390,6 @@ void SpringUnitSyncLib::_Load( const wxString& path )
 		GetLibFuncPtr( m_libhandle, _T("GetModValidMapCount"),				m_get_mod_valid_map_count );
 		GetLibFuncPtr( m_libhandle, _T("GetModValidMap"),					m_get_valid_map );
 
-		GetLibFuncPtr( m_libhandle, _T("GetLuaAICount"),					m_get_luaai_count );
-		GetLibFuncPtr( m_libhandle, _T("GetLuaAIName"),						m_get_luaai_name );
-		GetLibFuncPtr( m_libhandle, _T("GetLuaAIDesc"),						m_get_luaai_desc );
-
 		GetLibFuncPtr( m_libhandle, _T("GetMapOptionCount"),				m_get_map_option_count );
 		GetLibFuncPtr( m_libhandle, _T("GetCustomOptionCount"),				m_get_custom_option_count );
 		GetLibFuncPtr( m_libhandle, _T("GetModOptionCount"),				m_get_mod_option_count );
@@ -450,13 +597,12 @@ wxArrayString SpringUnitSyncLib::GetUnitsyncErrors() const
       ret.Add( msg );
       msg = WX_STRINGC( m_get_next_error() );
     }
-    return ret;
   }
   catch ( unitsync_assert &e )
   {
     ret.Add( WX_STRINGC( e.what() ) );
-    return ret;
   }
+  return ret;
 }
 
 
@@ -767,7 +913,7 @@ wxImage SpringUnitSyncLib::GetMetalmap( const wxString& mapFileName )
 
   typedef unsigned char uchar;
   wxImage metalmap(width, height, false);
-  uninitialized_array<uchar> grayscale(width * height);
+  LSL::Util::uninitialized_array<uchar> grayscale(width * height);
   uchar* true_colours = metalmap.GetData();
 
   retval = m_get_infomap(mapFileName.mb_str(wxConvUTF8), "metal", grayscale, 1 /*byte per pixel*/);
@@ -797,7 +943,7 @@ wxImage SpringUnitSyncLib::GetHeightmap( const wxString& mapFileName )
   typedef unsigned char uchar;
   typedef unsigned short ushort;
   wxImage heightmap(width, height, false);
-  uninitialized_array<ushort> grayscale(width * height);
+  LSL::Util::uninitialized_array<ushort> grayscale(width * height);
   uchar* true_colours = heightmap.GetData();
 
   retval = m_get_infomap(mapFileName.mb_str(wxConvUTF8), "height", grayscale, 2 /*byte per pixel*/);
@@ -1103,30 +1249,6 @@ void SpringUnitSyncLib::CloseFileVFS( int handle )
 }
 
 
-int SpringUnitSyncLib::GetLuaAICount( const wxString& modname )
-{
-  InitLib( m_get_luaai_count );
-
-  _SetCurrentMod( modname );
-  return m_get_luaai_count();
-}
-
-
-wxString SpringUnitSyncLib::GetLuaAIName( int aiIndex )
-{
-  InitLib( m_get_luaai_name );
-
-  return WX_STRINGC(m_get_luaai_name( aiIndex ));
-}
-
-
-wxString SpringUnitSyncLib::GetLuaAIDesc( int aiIndex )
-{
-  InitLib( m_get_luaai_desc );
-
-  return WX_STRINGC( m_get_luaai_desc( aiIndex ) );
-}
-
 unsigned int SpringUnitSyncLib::GetValidMapCount( const wxString& modname )
 {
   InitLib( m_get_mod_valid_map_count );
