@@ -4,16 +4,16 @@
 //
 
 #include "stacktrace.h"
-
+#include "utils/conversion.h"
 #if defined(ENABLE_DEBUG_REPORT)
 
 #if wxUSE_STACKWALKER
 
 void StackTrace::OnStackFrame ( const wxStackFrame& frame )
 {
-//  StackTraceString += wxString::Format( _T("(%d) "), frame.GetLevel() ); // (frame_level_number)
-//  PartToHash += wxString::Format( _T("(%d) "), frame.GetLevel() );
-  StackTraceString += wxString::Format( _T("%p "), frame.GetAddress() ); // [calling_address]
+//  StackTraceString += wxFormat( _T("(%d) "), frame.GetLevel() ); // (frame_level_number)
+//  PartToHash += wxFormat( _T("(%d) "), frame.GetLevel() );
+  StackTraceString += wxFormat( _T("%p ") ) % frame.GetAddress(); // [calling_address]
 
 
     StackTraceString += frame.GetName();  // function_name
@@ -43,7 +43,7 @@ void StackTrace::OnStackFrame ( const wxStackFrame& frame )
         if ( paramcount > 0 ) StackTraceString += _T(",");
       }
     }
-	StackTraceString += _T(" ") + frame.GetFileName() + wxString::Format( _T(":%d"), frame.GetLine() ); // File: file_name : line_number
+	StackTraceString += _T(" ") + frame.GetFileName() + wxFormat( _T(":%d") ) % frame.GetLine(); // File: file_name : line_number
 
   }
   StackTraceString += _T("\n");
