@@ -36,17 +36,15 @@
 #include "updater/updatehelper.h"
 #include "uiutils.h"
 #include "chatpanel.h"
-#include "battlelisttab.h"
-#include "battleroomtab.h"
+#include "battlelist/battlelisttab.h"
+#include "hosting/battleroomtab.h"
+#include "hosting/mainjoinbattletab.h"
+#include "hosting/mainsingleplayertab.h"
 #include "battle.h"
 #include "mainchattab.h"
-#include "mainjoinbattletab.h"
-#include "mainsingleplayertab.h"
 #include "crashreport.h"
-#ifndef NO_TORRENT_SYSTEM
-#include "maintorrenttab.h"
-#include "torrentwrapper.h"
-#endif
+#include "maindownloadtab.h"
+#include "downloader/prdownloader.h"
 
 #include "agreementdialog.h"
 #ifdef __WXMSW__
@@ -59,7 +57,7 @@
 #include "utils/customdialogs.h"
 #include "utils/platform.h"
 #include "updater/versionchecker.h"
-#include "alsound.h"
+#include "sound/alsound.h"
 #include "globalsmanager.h"
 #include "utils/misc.h"
 
@@ -339,49 +337,23 @@ void Ui::Quit()
 
 void Ui::DownloadMap( const wxString& /*hash*/, const wxString& name )
 {
-#ifndef NO_TORRENT_SYSTEM
-    DownloadFileP2P( name );
-#else
-	DownloadFileWebsite( name );
-#endif
+    std::string sname = STD_STRING(name);
+    int count = prDownloader().GetMap(sname);
+    assert( count > 0 );
 }
 
-
 void Ui::DownloadMod( const wxString& /*hash*/, const wxString& name )
 {
-#ifndef NO_TORRENT_SYSTEM
-    DownloadFileP2P( name );
-#else
-	DownloadFileWebsite( name );
-#endif
-}
-
-void Ui::DownloadFileP2P( const wxString& name )
-{
-#ifndef NO_TORRENT_SYSTEM
-	if ( usync().IsLoaded() )
-    {
-        wxFormat msg(_("Queued download of %s"));
-        UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent(
-                    UiEvents::StatusData( (msg % name).str(), 1 ) );
-		torrent().RequestFileByName( name );
-    }
-	else
-	{
-		customMessageBoxNoModal( SL_MAIN_ICON, _("To use the integrated downloader the unitsync library needs to be loaded.\n" \
-												 "Please check for correct path in Edit->Preferences->Spring"), _("Unitsync not loaded") );
-	}
-#endif
-}
-
-void Ui::DownloadFileWebsite( const wxString& name )
-{
-	wxString newname = name;
-	newname.Replace( _T(" "), _T("+") );
-	wxString url = _T("http://spring.jobjol.nl/search_result.php?search_cat=1&select_select=select_file_subject&Submit=Search&search=") + newname;
-	OpenWebBrowser ( url );
+    prDownloader().GetGame( STD_STRING(name) );
 }
 
+//void Ui::DownloadFileWebsite( const wxString& name )
+//{
+//	wxString newname = name;
+//	newname.Replace( _T(" "), _T("+") );
+//	wxString url = _T("http://spring.jobjol.nl/search_result.php?search_cat=1&select_select=select_file_subject&Submit=Search&search=") + newname;
+//	OpenWebBrowser ( url );
+//}
 
 //! @brief Display a dialog asking a question with OK and Canel buttons
 //!
@@ -561,14 +533,12 @@ void Ui::OnUpdate( int mselapsed )
 #endif
     }
 
-#ifndef NO_TORRENT_SYSTEM
     if (m_upd_counter_torrent % 20 == 0 )
     {
-        mw().GetTorrentTab().OnUpdate();
+		mw().GetDownloadTab().OnUpdate();
     }
-//    torrent().UpdateFromTimer( mselapsed );
+//    prDownloader().UpdateFromTimer( mselapsed );
     m_upd_counter_torrent++;
-#endif
 }
 
 
@@ -604,7 +574,7 @@ bool Ui::IsSpringCompatible()
     if ( neededversion == _T("*") ) return true; // Server accepts any version.
     else if ( neededversion.IsEmpty() ) return false;
     std::map<wxString, wxString> versionlist = sett().GetSpringVersionList();
-    if ( versionlist.size() == 0 )
+    if ( versionlist.empty() )
     {
       wxLogWarning( _T("can't get spring version from any unitsync") );
       customMessageBoxNoModal(SL_MAIN_ICON,  _("Couldn't get your spring versions from any unitsync library.\n\nOnline play is currently disabled."), _("Spring error"), wxICON_EXCLAMATION|wxOK );
@@ -1191,18 +1161,15 @@ void Ui::OnSaidBattle( IBattle& /*battle*/, const wxString& nick, const wxString
 void Ui::OnSpringStarting()
 {
   m_ingame = true;
-#ifndef NO_TORRENT_SYSTEM
-  torrent().SetIngameStatus(m_ingame);
-#endif
+  prDownloader().SetIngameStatus( m_ingame );
 }
 
 
 void Ui::OnSpringTerminated( long exit_code )
 {
     m_ingame = false;
-#ifndef NO_TORRENT_SYSTEM
-    torrent().SetIngameStatus(m_ingame);
-#endif
+	prDownloader().SetIngameStatus( m_ingame );
+
     if ( !m_serv ) return;
 
     try {
@@ -1251,38 +1218,36 @@ void Ui::OnRing( const wxString& from )
 		UiEvents::GetNotificationEventSender().SendEvent(
 				UiEvents::NotficationData( UiEvents::ServerConnection, wxFormat(_("%s:\nring!") ) % from ) );
 	}
+	const Battle* battle = serverSelector().GetServer().GetCurrentBattle();
+	if ( (battle != NULL) && (battle->GetMe().GetBattleStatus().sync == SYNC_UNSYNCED)) {
+		wxString host_map_name = serverSelector().GetServer().GetCurrentBattle()->GetHostMapName();
+//        if(! usync().MapExists(host_map_name)) {//TODO
 
-#ifndef NO_TORRENT_SYSTEM
-    if(serverSelector().GetServer().GetCurrentBattle()->GetMe().GetBattleStatus().sync == SYNC_UNSYNCED) {
-        wxString host_map_name = serverSelector().GetServer().GetCurrentBattle()->GetHostMapName();
-        if(! usync().MapExists(host_map_name)) {
+//			map_infos info_map = prDownloader().CollectGuiInfos();
+//            bool dling = false;
 
-            map_infos info_map = torrent().CollectGuiInfos();
-            bool dling = false;
+//            for(map_infos_iter iter = info_map.begin(); iter != info_map.end(); ++iter){
+//                if(iter->first == wxString(_T("global")))
+//                    continue;
+//                else if(iter->first == host_map_name) {
+//                    int eta = iter->second.eta;
 
-            for(map_infos_iter iter = info_map.begin(); iter != info_map.end(); ++iter){
-                if(iter->first == wxString(_T("global")))
-                    continue;
-                else if(iter->first == host_map_name) {
-                    int eta = iter->second.eta;
-
-                    if(eta <= 0) {
-						serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(_("/me map is not available for automatic downloading."));
-                    } else {
-                        serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(wxString::Format(
-                                _("/me downloading map eta: %d s"), eta)
-                        );
-                    dling = true;
-                    }
-                }
-            }
-            if(! dling) { //XXX is it possible to get eta from web dl in sl?, anyone using it instead torrent system? //there is no direct from-web downloading in SL currently
-                serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(
-                        _("/me is not downloading map with SL torrent system"));
-            }
-        }
+//                    if(eta <= 0) {
+//						serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(_("/me map is not available for automatic downloading."));
+//                    } else {
+//                        serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(wxString::Format(
+//                                _("/me downloading map eta: %d s"), eta)
+//                        );
+//                    dling = true;
+//                    }
+//                }
+//            }
+//            if(! dling) { //XXX is it possible to get eta from web dl in sl?, anyone using it instead torrent system? //there is no direct from-web downloading in SL currently
+//                serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(
+//                        _("/me is not downloading map with SL torrent system"));
+//            }
+//        }
     }
-#endif
 
 #ifndef DISABLE_SOUND
     if ( sett().GetChatPMSoundNotificationEnabled() )
@@ -1378,7 +1343,16 @@ void Ui::FirstRunWelcome()
 		IntroGuide* intro = new IntroGuide();
 		intro->Show();
 
-        CopyUikeys( sett().GetCurrentUsedDataDir() );
+		// copy uikeys.txt
+		wxPathList pl;
+		pl.AddEnvList( _T("%ProgramFiles%") );
+		pl.AddEnvList( _T("XDG_DATA_DIRS") );
+        pl = PathlistFactory::AdditionalSearchPaths( pl );
+		wxString uikeyslocation = pl.FindValidPath( _T("uikeys.txt") );
+		if ( !uikeyslocation.IsEmpty() )
+		{
+			wxCopyFile( uikeyslocation, sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("uikeys.txt"), false );
+		}
 
     #ifdef __WXMSW__
         if ( TASClientPresent() &&
