@@ -9,13 +9,13 @@
 //for updating ui, anybody feel free to replace with fancy events stuff :P
 #include "ui.h"
 #include "mainwindow.h"
-#include "mainjoinbattletab.h"
 #include "mainchattab.h"
-#include "battlelisttab.h"
-#include "battleroomtab.h"
+#include "hosting/mainjoinbattletab.h"
+#include "hosting/battleroomtab.h"
+#include "battlelist/battlelisttab.h"
 #include "chatpanel.h"
-#include "mainoptionstab.h"
-#include "groupoptionspanel.h"
+#include <options/mainoptionstab.h>
+#include <options/groupoptionspanel.h>
 #include "globalsmanager.h"
 
 UserActions& useractions()
