@@ -50,7 +50,7 @@ inline wxString TowxString(const wxChar *arg){
 //}
 
 template<class T>
-static inline T FromwxString(const wxString& arg){
+inline T FromwxString(const wxString& arg){
   std::stringstream s;
   s << STD_STRING(arg);
   int64_t ret;
@@ -60,6 +60,16 @@ static inline T FromwxString(const wxString& arg){
 
 #ifdef SL_QT_MODE
 #include <QString>
+#include <QVariant>
+template<>
+inline QString FromwxString(const wxString& arg) {
+        return QString(arg.mb_str());
+}
+template<>
+inline QVariant FromwxString(const wxString& arg) {
+        return QVariant::fromValue( FromwxString<QString>( arg ) );
+}
+
 template<>
 inline wxString TowxString(QString arg){
   return wxString(arg.toStdString().c_str(),wxConvUTF8);
@@ -123,9 +133,12 @@ class StringtokenizerVectorized : public std::vector<wxString> {
 //! a wxString extension class to boost::format
 struct wxFormat : public boost::format
 {
-	wxFormat( const wxString& format )
+    explicit wxFormat( const wxString& format )
 		: boost::format( STD_STRING( format ) )
 	{}
+    explicit wxFormat( const std::string& format )
+        : boost::format( format )
+    {}
 
 	wxString str() const
 	{
