@@ -32,12 +32,15 @@ class assert_exception : public std::runtime_error
 #define ASSERT_EXCEPTION(cond,msg) if(!(cond))\
 {wxLogMessage(_T("runtime assertion ( %s:%d ): %s"), TowxString(__FILE__).c_str(),__LINE__ , wxString(msg).c_str() );throw assert_exception(std::string(wxString(msg).mb_str()));}
 
+#define CATCH_ANY catch(...)\
+{wxLogMessage(_T("%s-%d: undiff exception"),TowxString(__FILE__).c_str(),__LINE__ );}
+
 
 #endif // SPRINGLOBBY_HEADERGUARD_DEBUG_H
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
