@@ -23,7 +23,7 @@
 #include "conversion.h"
 #include "../updater/versionchecker.h"
 #include "customdialogs.h"
-#include "math.h"
+#include <lslutils/misc.h>
 #include "../crashreport.h"
 
 #ifdef SL_QT_MODE
@@ -75,7 +75,7 @@ wxLogWindow* InitializeLoggingTargets( wxFrame* parent, bool console, const wxSt
         logChain = new wxLogChain( loggerwin );
     }
 
-    #if wxUSE_DEBUGREPORT && defined(ENABLE_DEBUG_REPORT)
+    #if wxUSE_DEBUGREPORT && defined(ENABLE_DEBUG_REPORT) && wxUSE_STD_IOSTREAM
         ///hidden stream logging for crash reports
         wxLog *loggercrash = new wxLogStream( &CrashReport::instance().crashlog );
         logChain = new wxLogChain( loggercrash );
@@ -181,7 +181,7 @@ wxString GetHostCPUSpeed()
       }
     }
 #endif
-    return TowxString( clamp( max_cpu_speed,0,max_cpu_speed ) );
+    return TowxString( LSL::Util::Clamp( max_cpu_speed,0,max_cpu_speed ) );
 }
 
 
@@ -321,7 +321,7 @@ bool WinExecuteAdmin( const wxString& command, const wxString& params )
 
       shExecInfo.cbSize = sizeof(SHELLEXECUTEINFO);
 
-      shExecInfo.fMask = NULL;
+      shExecInfo.fMask = 0;
       shExecInfo.hwnd = NULL;
 
       //on XP this would open the real runas dialog, which apparently is its own wonder
@@ -350,7 +350,7 @@ bool WinExecute( const wxString& command, const wxString& params )
 
       shExecInfo.cbSize = sizeof(SHELLEXECUTEINFO);
     shExecInfo.lpVerb = _T("open");
-      shExecInfo.fMask = NULL;
+      shExecInfo.fMask = 0;
       shExecInfo.hwnd = NULL;
 
 #ifdef _MSC_VER //some strange compiler stupidity going on here
@@ -403,7 +403,7 @@ wxString GetAppName( const bool lowerCase )
 	return name;
 }
 
-wxString IdentityString(const wxString format, bool lowerCase )
+wxString IdentityString(const wxString& format, bool lowerCase )
 {
 	return wxFormat( format ) %  GetAppName( lowerCase ) ;
 }
