@@ -27,8 +27,8 @@
 #include "wx/hashset.h"
 #include "wx/checkbox.h"
 
-#include "../settings++/hotkeys/HotkeyTypes.h"
-#include "../settings++/hotkeys/CommandOrderDlg.h"
+
+#include "../springsettings/hotkeys/CommandOrderDlg.h"
 
 
 // The maximum number of shortcuts associated with each wxCmd.
@@ -365,23 +365,21 @@ public:     // static
 
 public:
 
-    wxCmd(const wxKeyBind &first, int id,
-        const wxString &name = wxEmptyString,
-        const wxString &desc = wxEmptyString) {
-        m_strName = name;
-        m_strDescription = desc;
-        m_nShortcuts = 1;
+    wxCmd(const wxKeyBind &first, int id, const wxString &name = wxEmptyString, const wxString &desc = wxEmptyString):
+        m_nShortcuts(1),
+        m_strName(name),
+        m_strDescription(desc),
+        m_nId(id)
+	{
         m_keyShortcut[0] = first;
-        m_nId = id;
     }
 
-    wxCmd(int id = wxID_INVALID,
-        const wxString &name = wxEmptyString,
-        const wxString &desc = wxEmptyString) {
-        m_strName = name;
-        m_strDescription = desc;
-        m_nId = id;
-        m_nShortcuts = 0;
+    wxCmd(int id = wxID_INVALID, const wxString &name = wxEmptyString, const wxString &desc = wxEmptyString):
+        m_nShortcuts(0),
+        m_strName(name),
+        m_strDescription(desc),
+        m_nId(id)
+    {
     }
 
     virtual void DeepCopy(const wxCmd *cmd) {
@@ -686,9 +684,6 @@ private:
     #define wxADD_KEYBINDER_SUPPORT()           /* expand to nothing */
 
 #endif
-//added by vbs
-//WX_DECLARE_HASH_SET(int, wxIntegerHash, wxIntegerEqual, IdSet);
-//WX_DECLARE_HASH_SET(wxCmd*, wxPointerHash, wxPointerEqual, CmdSet);
 
 //! This is the real keybinder. This object is an event handler which
 //! can be #Attach()ed to any wxWindow to intercept the keypresses
