@@ -26,5 +26,5 @@ ZIPFILEBASE=$(echo $(basename $1))
 TOPLEVELDIR=${ZIPFILEBASE%".zip"}
 unzip ${ZIPFILE}
 rm ${ZIPFILE}
-cd ${TOPLEVELDIR} && ${STRIP} boost*.dll wx*.dll mingwm10.dll && zip -r ${ZIPFILE} * locale/\* || exit 1
+cd ${TOPLEVELDIR} && rm -f *pr-downloader* springsettings.exe && zip -r ${ZIPFILE} * locale/\* || exit 1
 exit 0
